pub(crate) async fn rehydrate_user(
session: Option<SessionKey>,
) -> Result<Option<PasswordManagerClient>>Expand description
Rehydrate a [PasswordManagerClient] from the persisted session database.
Returns Ok(None) when no session has been persisted yet. Failures to load from state or unlock
with the provided session key are logged as warnings and fail gracefully into a logged out or
locked state respectively, to match the old CLI behavior.